@@ -10,8 +10,7 @@ from blitzly.etc.utils import save_show_return, update_figure_layout
 def _check_shape_for_subplots(
     subfig_list: List[BaseFigure], shape: Tuple[int, int]
 ) -> None:
-    """
-    Checks whether the `shape` is compatible for making subplots.
+    """Checks whether the `shape` is compatible for making subplots.
 
     Args:
         subfig_list (List[BaseFigure]): A list of figure objects.
@@ -36,15 +35,15 @@ def make_subplots(
     shared_xaxes: bool = False,
     shared_yaxes: bool = False,
     plotly_kwargs: Optional[dict] = None,
+    show_legend: bool = False,
     size: Optional[Tuple[int, int]] = None,
     show: bool = True,
     write_html_path: Optional[str] = None,
 ) -> BaseFigure:
-
-    """
-    Creates subplots using a provided list of figure objects.
-    `plotly.subplots.make_subplots` requires the use of traces. This function is an
-    alternative implementation that directly uses previously-created figure objects.
+    """Creates subplots using a provided list of figure objects.
+    `plotly.subplots.make_subplots` requires the use of traces. This function
+    is an alternative implementation that directly uses previously-created
+    figure objects.
 
     Example:
     ```python
@@ -62,11 +61,12 @@ def make_subplots(
         subfig_list (List[BaseFigure]): A list of figure objects.
         shape (Tuple[int, int]): The grid shape of the subplots.
         title (str): Title of the plot.
-        column_width (Optional[List[float]]): The width of each column in the subplot grid.
+        column_widths (Optional[List[float]]): The width of each column in the subplot grid.
         fill_row (bool): If True, resize the last subplot in the grid to fill the row.
         shared_xaxes (bool): Share the x-axis labels along each column.
         shared_yaxes (bool): Share the y-axis labels along each row.
         plotly_kwargs (Optional[dict]): Additional keyword arguments to pass to Plotly `subplots.make_subplots`.
+        show_legend (bool): Whether to show the legend.
         size (Optional[Tuple[int, int]): Size of the plot.
         show (bool): Whether to show the figure.
         write_html_path (Optional[str]): The path to which the histogram should be written as an HTML file.
@@ -111,7 +111,7 @@ def make_subplots(
         row = idx // shape[1]
         col = idx % shape[1]
         for trace in traces:
-            fig.append_trace(trace, row=row + 1, col=col + 1)
+            fig.add_trace(trace, row=row + 1, col=col + 1)
 
         if row != shape[0] - 1 and shared_xaxes:
             subplot_axes_labels[0][idx] = ""
@@ -124,6 +124,6 @@ def make_subplots(
             title_text=subplot_axes_labels[1][idx], row=row + 1, col=col + 1
         )
 
-    fig.update_layout(showlegend=False)
+    fig.update_layout(showlegend=show_legend)
     fig = update_figure_layout(fig, title, size)
     return save_show_return(fig, write_html_path, show)
